@@ -1,5 +1,5 @@
 package Selenium::ActionChains;
-$Selenium::ActionChains::VERSION = '1.37';
+$Selenium::ActionChains::VERSION = '1.40';
 use strict;
 use warnings;
 
@@ -129,9 +129,11 @@ sub key_down {
     if ( defined($element) ) {
         $self->click($element);
     }
-    push @{ $self->actions },
-      sub { $self->driver->send_keys_to_active_element(@$value) };
-    $self;
+    foreach my $v (@$value) {
+        push @{ $self->actions },
+          sub { $self->driver->general_action( actions => [ { type => 'key', id => 'key', actions => [ { type => 'keyDown', value => $v } ] } ] ) };
+    }
+    return $self;
 }
 
 sub key_up {
@@ -140,9 +142,11 @@ sub key_up {
     if ( defined($element) ) {
         $self->click($element);
     }
-    push @{ $self->actions },
-      sub { $self->driver->send_keys_to_active_element(@$value) };
-    $self;
+    foreach my $v (@$value) {
+        push @{ $self->actions },
+          sub { $self->driver->$self->driver->general_action( actions => [ { type => 'key', id => 'key', actions => [ { type => 'keyUp', value => $v } ] } ] ) };
+    }
+    return $self;
 }
 
 sub send_keys {
@@ -174,7 +178,7 @@ Selenium::ActionChains - Action chains for Selenium::Remote::Driver
 
 =head1 VERSION
 
-version 1.37
+version 1.40
 
 =head1 SYNOPSIS
 
@@ -401,30 +405,19 @@ Sends keys to an element
         my $element = $driver->find_element('foo','id');
         $action_chains->send_keys_to_element($element,'abcd');
 
-=head1 SEE ALSO
+=head1 AUTHORS
 
-Please see those modules/websites for more information related to this module.
+Current Maintainers:
 
 =over 4
 
 =item *
 
-L<Selenium::Remote::Driver|Selenium::Remote::Driver>
+George S. Baugh <george@troglodyne.net>
 
 =back
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/teodesian/Selenium-Remote-Driver/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 AUTHORS
-
-Current Maintainers:
+Previous maintainers:
 
 =over 4
 
@@ -436,12 +429,6 @@ Daniel Gempesaw <gempesaw@gmail.com>
 
 Emmanuel Peroumalnaïk <peroumalnaik.emmanuel@gmail.com>
 
-=back
-
-Previous maintainers:
-
-=over 4
-
 =item *
 
 Luke Closs <cpan@5thplane.com>
@@ -468,6 +455,8 @@ Copyright (c) 2010-2011 Aditya Ivaturi, Gordon Child
 
 Copyright (c) 2014-2017 Daniel Gempesaw
 
+Copyright (c) 2018-2021 George S. Baugh
+
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
