@@ -1,5 +1,5 @@
 package Selenium::CanStartBinary;
-$Selenium::CanStartBinary::VERSION = '1.37';
+$Selenium::CanStartBinary::VERSION = '1.40';
 use strict;
 use warnings;
 
@@ -381,7 +381,7 @@ Selenium::CanStartBinary - Teach a WebDriver how to start its own binary aka no
 
 =head1 VERSION
 
-version 1.37
+version 1.40
 
 =head1 DESCRIPTION
 
@@ -536,40 +536,23 @@ Setting this will redirect it to the provided file.
 
 =head1 SEE ALSO
 
-Please see those modules/websites for more information related to this module.
+Selenium::Chrome
+Selenium::Firefox
+Selenium::PhantomJS
+
+=head1 AUTHORS
+
+Current Maintainers:
 
 =over 4
 
 =item *
 
-L<Selenium::Remote::Driver|Selenium::Remote::Driver>
-
-=item *
-
-L<Selenium::Chrome|Selenium::Chrome>
-
-=item *
-
-L<Selenium::Firefox|Selenium::Firefox>
-
-=item *
-
-L<Selenium::PhantomJS|Selenium::PhantomJS>
+George S. Baugh <george@troglodyne.net>
 
 =back
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/teodesian/Selenium-Remote-Driver/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 AUTHORS
-
-Current Maintainers:
+Previous maintainers:
 
 =over 4
 
@@ -581,12 +564,6 @@ Daniel Gempesaw <gempesaw@gmail.com>
 
 Emmanuel Peroumalnaïk <peroumalnaik.emmanuel@gmail.com>
 
-=back
-
-Previous maintainers:
-
-=over 4
-
 =item *
 
 Luke Closs <cpan@5thplane.com>
@@ -613,6 +590,8 @@ Copyright (c) 2010-2011 Aditya Ivaturi, Gordon Child
 
 Copyright (c) 2014-2017 Daniel Gempesaw
 
+Copyright (c) 2018-2021 George S. Baugh
+
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
