@@ -1,5 +1,5 @@
 package Selenium::CanStartBinary::FindBinary;
-$Selenium::CanStartBinary::FindBinary::VERSION = '1.37';
+$Selenium::CanStartBinary::FindBinary::VERSION = '1.40';
 use strict;
 use warnings;
 
@@ -45,7 +45,7 @@ sub _validate_manual_binary {
 
     my $abs_executable = eval {
         my $path = abs_path($executable);
-        die unless -e $path;
+        die if $path && !-f $path;
         $path;
     };
 
@@ -86,34 +86,23 @@ Selenium::CanStartBinary::FindBinary - Coercions for finding webdriver binaries
 
 =head1 VERSION
 
-version 1.37
+version 1.40
 
 =for Pod::Coverage *EVERYTHING*
 
-=head1 SEE ALSO
+=head1 AUTHORS
 
-Please see those modules/websites for more information related to this module.
+Current Maintainers:
 
 =over 4
 
 =item *
 
-L<Selenium::Remote::Driver|Selenium::Remote::Driver>
+George S. Baugh <george@troglodyne.net>
 
 =back
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/teodesian/Selenium-Remote-Driver/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 AUTHORS
-
-Current Maintainers:
+Previous maintainers:
 
 =over 4
 
@@ -125,12 +114,6 @@ Daniel Gempesaw <gempesaw@gmail.com>
 
 Emmanuel Peroumalnaïk <peroumalnaik.emmanuel@gmail.com>
 
-=back
-
-Previous maintainers:
-
-=over 4
-
 =item *
 
 Luke Closs <cpan@5thplane.com>
@@ -157,6 +140,8 @@ Copyright (c) 2010-2011 Aditya Ivaturi, Gordon Child
 
 Copyright (c) 2014-2017 Daniel Gempesaw
 
+Copyright (c) 2018-2021 George S. Baugh
+
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
