@@ -1,5 +1,5 @@
 package Selenium::Edge;
-$Selenium::Edge::VERSION = '1.37';
+$Selenium::Edge::VERSION = '1.40';
 use strict;
 use warnings;
 
@@ -18,7 +18,7 @@ has '+browser_name' => (
 has 'binary' => (
     is        => 'lazy',
     coerce    => \&coerce_simple_binary,
-    default   => sub { 'MicrosoftWebDriver.exe' },
+    default   => sub { 'msedgedriver.exe' },
     predicate => 1
 );
 
@@ -57,7 +57,7 @@ Selenium::Edge - Use EdgeDriver without a Selenium server
 
 =head1 VERSION
 
-version 1.37
+version 1.40
 
 =head1 SYNOPSIS
 
@@ -146,30 +146,19 @@ we can do.
 
 =for Pod::Coverage has_binary
 
-=head1 SEE ALSO
+=head1 AUTHORS
 
-Please see those modules/websites for more information related to this module.
+Current Maintainers:
 
 =over 4
 
 =item *
 
-L<Selenium::Remote::Driver|Selenium::Remote::Driver>
+George S. Baugh <george@troglodyne.net>
 
 =back
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/teodesian/Selenium-Remote-Driver/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 AUTHORS
-
-Current Maintainers:
+Previous maintainers:
 
 =over 4
 
@@ -181,12 +170,6 @@ Daniel Gempesaw <gempesaw@gmail.com>
 
 Emmanuel Peroumalnaïk <peroumalnaik.emmanuel@gmail.com>
 
-=back
-
-Previous maintainers:
-
-=over 4
-
 =item *
 
 Luke Closs <cpan@5thplane.com>
@@ -213,6 +196,8 @@ Copyright (c) 2010-2011 Aditya Ivaturi, Gordon Child
 
 Copyright (c) 2014-2017 Daniel Gempesaw
 
+Copyright (c) 2018-2021 George S. Baugh
+
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
