@@ -1,5 +1,5 @@
 package Selenium::Remote::ErrorHandler;
-$Selenium::Remote::ErrorHandler::VERSION = '1.37';
+$Selenium::Remote::ErrorHandler::VERSION = '1.40';
 use strict;
 use warnings;
 
@@ -154,7 +154,7 @@ Selenium::Remote::ErrorHandler - Error handler for Selenium::Remote::Driver
 
 =head1 VERSION
 
-version 1.37
+version 1.40
 
 =head1 SUBROUTINES
 
@@ -165,30 +165,19 @@ Instead of just returning the end user a server returned error code, this return
 Used internally in Selenium::Remote::Driver, but overriding this might be useful in some situations.
 You could additionally alter the STATUS_CODE parameter of this module to add extra handlers if the situation warrants it.
 
-=head1 SEE ALSO
+=head1 AUTHORS
 
-Please see those modules/websites for more information related to this module.
+Current Maintainers:
 
 =over 4
 
 =item *
 
-L<Selenium::Remote::Driver|Selenium::Remote::Driver>
+George S. Baugh <george@troglodyne.net>
 
 =back
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/teodesian/Selenium-Remote-Driver/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 AUTHORS
-
-Current Maintainers:
+Previous maintainers:
 
 =over 4
 
@@ -200,12 +189,6 @@ Daniel Gempesaw <gempesaw@gmail.com>
 
 Emmanuel Peroumalnaïk <peroumalnaik.emmanuel@gmail.com>
 
-=back
-
-Previous maintainers:
-
-=over 4
-
 =item *
 
 Luke Closs <cpan@5thplane.com>
@@ -232,6 +215,8 @@ Copyright (c) 2010-2011 Aditya Ivaturi, Gordon Child
 
 Copyright (c) 2014-2017 Daniel Gempesaw
 
+Copyright (c) 2018-2021 George S. Baugh
+
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
