@@ -1,5 +1,5 @@
 package Selenium::Remote::RemoteConnection;
-$Selenium::Remote::RemoteConnection::VERSION = '1.37';
+$Selenium::Remote::RemoteConnection::VERSION = '1.40';
 use strict;
 use warnings;
 
@@ -49,7 +49,8 @@ sub check_status {
         croak "Could not connect to SeleniumWebDriver: $_";
     };
 
-    if ( $status->{cmd_status} ne 'OK' ) {
+    my $cmdOut = $status->{cmd_status} || '';
+    if ( $cmdOut ne 'OK' ) {
 
         # Could be grid, see if we can talk to it
         $status = undef;
@@ -57,7 +58,7 @@ sub check_status {
           $self->request( { method => 'GET', url => 'grid/api/hub/status' } );
     }
 
-    unless ( $status->{cmd_status} eq 'OK' ) {
+    unless ( $cmdOut eq 'OK' ) {
         croak "Selenium server did not return proper status";
     }
 }
@@ -235,7 +236,7 @@ Selenium::Remote::RemoteConnection - Connect to a selenium server
 
 =head1 VERSION
 
-version 1.37
+version 1.40
 
 =head1 SYNOPSIS
 
@@ -279,30 +280,19 @@ Croaks unless the selenium server is responsive.  Sometimes is useful to call in
 
 Make a request of the Selenium server.  Mostly useful for debugging things going wrong with Selenium::Remote::Driver when not in normal operation.
 
-=head1 SEE ALSO
+=head1 AUTHORS
 
-Please see those modules/websites for more information related to this module.
+Current Maintainers:
 
 =over 4
 
 =item *
 
-L<Selenium::Remote::Driver|Selenium::Remote::Driver>
+George S. Baugh <george@troglodyne.net>
 
 =back
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/teodesian/Selenium-Remote-Driver/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 AUTHORS
-
-Current Maintainers:
+Previous maintainers:
 
 =over 4
 
@@ -314,12 +304,6 @@ Daniel Gempesaw <gempesaw@gmail.com>
 
 Emmanuel Peroumalnaïk <peroumalnaik.emmanuel@gmail.com>
 
-=back
-
-Previous maintainers:
-
-=over 4
-
 =item *
 
 Luke Closs <cpan@5thplane.com>
@@ -346,6 +330,8 @@ Copyright (c) 2010-2011 Aditya Ivaturi, Gordon Child
 
 Copyright (c) 2014-2017 Daniel Gempesaw
 
+Copyright (c) 2018-2021 George S. Baugh
+
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
