@@ -1,5 +1,5 @@
 package Selenium::Remote::WebElement;
-$Selenium::Remote::WebElement::VERSION = '1.37';
+$Selenium::Remote::WebElement::VERSION = '1.40';
 # ABSTRACT: Representation of an HTML Element used by Selenium Remote Driver
 
 use strict;
@@ -64,6 +64,24 @@ sub click {
 }
 
 
+sub execute_script {
+    my ($self, $script, @args) = @_;
+    return $self->driver->execute_script(
+        $script,
+        { 'element-6066-11e4-a52e-4f735466cecf' => $self->{id} },
+        @args );
+}
+
+sub execute_async_script {
+    my ($self, $script, @args) = @_;
+    return $self->driver->execute_async_script(
+        $script,
+        { 'element-6066-11e4-a52e-4f735466cecf' => $self->{id} },
+        @args );
+}
+
+
+
 sub submit {
     my ($self) = @_;
     if (
@@ -111,7 +129,8 @@ sub send_keys {
 sub is_selected {
     my ($self) = @_;
 
-    return $self->get_property('checked')
+    my $to_check = $self->get_tag_name() eq 'option' ? 'selected' : 'checked';
+    return $self->get_property($to_check)
       if $self->driver->{is_wd3}
       && !( grep { $self->driver->browser_name eq $_ }
         qw{chrome MicrosoftEdge} );
@@ -395,7 +414,7 @@ Selenium::Remote::WebElement - Representation of an HTML Element used by Seleniu
 
 =head1 VERSION
 
-version 1.37
+version 1.40
 
 =head1 DESCRIPTION
 
@@ -477,6 +496,11 @@ Alias to Selenium::Remote::Driver::find_child_element and find_child_elements, r
  Usage:
     $elem->click();
 
+=head2 execute_script($script, @args), execute_async_script($script, @args)
+
+Convenience method to execute a script with the element passed as the first argument to the script function, and the remaining args appended.
+See the documentation for Selenium::Remote::Driver::execute_script for more information.
+
 =head2 submit
 
  Description:
@@ -801,30 +825,19 @@ To conveniently write the screenshot to a file, see L</capture_screenshot>.
  Usage:
     $element->capture_screenshot($filename);
 
-=head1 SEE ALSO
+=head1 AUTHORS
 
-Please see those modules/websites for more information related to this module.
+Current Maintainers:
 
 =over 4
 
 =item *
 
-L<Selenium::Remote::Driver|Selenium::Remote::Driver>
+George S. Baugh <george@troglodyne.net>
 
 =back
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/teodesian/Selenium-Remote-Driver/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 AUTHORS
-
-Current Maintainers:
+Previous maintainers:
 
 =over 4
 
@@ -836,12 +849,6 @@ Daniel Gempesaw <gempesaw@gmail.com>
 
 Emmanuel Peroumalnaïk <peroumalnaik.emmanuel@gmail.com>
 
-=back
-
-Previous maintainers:
-
-=over 4
-
 =item *
 
 Luke Closs <cpan@5thplane.com>
@@ -868,6 +875,8 @@ Copyright (c) 2010-2011 Aditya Ivaturi, Gordon Child
 
 Copyright (c) 2014-2017 Daniel Gempesaw
 
+Copyright (c) 2018-2021 George S. Baugh
+
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
