@@ -1,5 +1,5 @@
 package Selenium::Waiter;
-$Selenium::Waiter::VERSION = '1.37';
+$Selenium::Waiter::VERSION = '1.40';
 use strict;
 use warnings;
 
@@ -16,6 +16,7 @@ sub wait_until (&%) {
         timeout  => 30,
         interval => 1,
         debug    => 0,
+        die      => 0,
         @_
     };
 
@@ -34,6 +35,7 @@ sub wait_until (&%) {
         }
         catch {
             $exception = $_;
+            die $_  if $args->{die};
             warn $_ if $args->{debug};
             return '';
         }
@@ -65,7 +67,7 @@ Selenium::Waiter - Provides a utility wait_until function
 
 =head1 VERSION
 
-version 1.37
+version 1.40
 
 =head1 SYNOPSIS
 
@@ -123,6 +125,11 @@ to see the massacre:
     # carps: "kept from dying" once a second for thirty seconds
     wait_until { die 'kept from dying' } debug => 1;
 
+If you want to die anyways, just pass die => 1 to wait_until instead:
+
+    # Dies on the first failure, do your own error handling:
+    wait_until { die 'oops' } die => 1;
+
 =head4 Timeouts and Intervals
 
 You can also customize the timeout, and/or the retry interval between
@@ -131,30 +138,19 @@ iterations.
     # prints hi three four times at 0, 3, 6, and 9 seconds
     wait_until { print 'hi'; '' } timeout => 10, interval => 3;
 
-=head1 SEE ALSO
+=head1 AUTHORS
 
-Please see those modules/websites for more information related to this module.
+Current Maintainers:
 
 =over 4
 
 =item *
 
-L<Selenium::Remote::Driver|Selenium::Remote::Driver>
+George S. Baugh <george@troglodyne.net>
 
 =back
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/teodesian/Selenium-Remote-Driver/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 AUTHORS
-
-Current Maintainers:
+Previous maintainers:
 
 =over 4
 
@@ -166,12 +162,6 @@ Daniel Gempesaw <gempesaw@gmail.com>
 
 Emmanuel Peroumalnaïk <peroumalnaik.emmanuel@gmail.com>
 
-=back
-
-Previous maintainers:
-
-=over 4
-
 =item *
 
 Luke Closs <cpan@5thplane.com>
@@ -198,6 +188,8 @@ Copyright (c) 2010-2011 Aditya Ivaturi, Gordon Child
 
 Copyright (c) 2014-2017 Daniel Gempesaw
 
+Copyright (c) 2018-2021 George S. Baugh
+
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
